==> nextcloud-13.0.1.tgz: nextcloud/apps/comments/l10n/ko.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "댓글",
    "New comment …" : "새로운 댓글 …",
    "Delete comment" : "댓글 삭제",
    "Post" : "게시",
    "Cancel" : "취소",
    "Edit comment" : "댓글 편집",
    "[Deleted user]" : "[삭제된 사용자]",
    "No comments yet, start the conversation!" : "아직 댓글이 없습니다. 대화를 시작하십시오!",
    "More comments …" : "더 많은 댓글 …",
    "Save" : "저장",
    "Allowed characters {count} of {max}" : "{count}/{max} 글자 사용 가능",
    "Error occurred while updating comment with id {id}" : "댓글 ID {id}을(를) 업데이트하는 동안 오류가 발생했습니다 ",
    "Error occurred while posting comment" : "댓글을 게시하는 중 오류가 발생했습니다",
    "_%n unread comment_::_%n unread comments_" : ["읽지 않은 댓글 %n개"],
    "Comment" : "설명",
    "You commented" : "댓글 남김",
    "%1$s commented" : "%1$s 님의 댓글",
    "{author} commented" : "{author} 님이 댓글 남김",
    "You commented on %1$s" : "%1$s에 댓글 남김",
    "You commented on {file}" : "{file}에 댓글 남김",
    "%1$s commented on %2$s" : "%2$s에 %1$s 님이 댓글 남김",
    "{author} commented on {file}" : "{author} 님이 {file}에 댓글 남김",
    "<strong>Comments</strong> for files" : "파일의 <strong>댓글</strong>",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "삭제된 사용자가 남긴 “%s”의 댓글에서 여러분을 언급함",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "삭제된 사용자가 남긴 “{file}”의 댓글에서 여러분을 언급함",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s 님이 “%2$s”에 남긴 댓글에서 여러분을 언급함",
    "{user} mentioned you in a comment on “{file}”" : "{user} 님이 “{file}”에 남긴 댓글에서 여러분을 언급함",
    "Unknown user" : "알 수 없는 사용자",
    "A (now) deleted user mentioned you in a comment on “%s”" : "(현재) 삭제된 사용자가 “%s”에 남긴 댓글에서 여러분을 언급함",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "(현재) 삭제된 사용자가 “{file}”에 남긴 댓글에서 여러분을 언급함"
},
"nplurals=1; plural=0;");

==> nextcloud-18.0.4.tgz: nextcloud/apps/comments/l10n/ko.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "댓글",
    "You commented" : "댓글 남김",
    "%1$s commented" : "%1$s 님의 댓글",
    "{author} commented" : "{author} 님이 댓글 남김",
    "You commented on %1$s" : "%1$s에 댓글 남김",
    "You commented on {file}" : "{file}에 댓글 남김",
    "%1$s commented on %2$s" : "%2$s에 %1$s 님이 댓글 남김",
    "{author} commented on {file}" : "{author} 님이 {file}에 댓글 남김",
    "<strong>Comments</strong> for files" : "파일의 <strong>댓글</strong>",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "삭제된 사용자가 남긴 “{file}”의 댓글에서 여러분을 언급함",
    "{user} mentioned you in a comment on “{file}”" : "{user} 님이 “{file}”에 남긴 댓글에서 여러분을 언급함",
    "Files app plugin to add comments to files" : "파일에 댓글을 남기는 파일 앱 플러그인",
    "Edit comment" : "댓글 편집",
    "Delete comment" : "댓글 삭제",
    "New comment …" : "새로운 댓글 …",
    "Post" : "게시",
    "Cancel" : "취소",
    "[Deleted user]" : "[삭제된 사용자]",
    "No comments yet, start the conversation!" : "아직 댓글이 없습니다. 대화를 시작하십시오!",
    "More comments …" : "더 많은 댓글 …",
    "Save" : "저장",
    "Allowed characters {count} of {max}" : "{count}/{max}글자 사용 가능",
    "Error occurred while retrieving comment with ID {id}" : "댓글 ID {id} 가져오기 오류",
    "Error occurred while updating comment with id {id}" : "댓글 ID {id}을(를) 업데이트하는 동안 오류가 발생했습니다 ",
    "Error occurred while posting comment" : "댓글을 게시하는 중 오류가 발생했습니다",
    "_%n unread comment_::_%n unread comments_" : ["읽지 않은 댓글 %n개"],
    "_1 new comment_::_{unread} new comments_" : ["새 댓글 {unread}개"],
    "Comment" : "설명"
},
"nplurals=1; plural=0;");
